==> senior_design_system-0.21.4.tar.gz: example/lib/pages/badge.example.dart <==
import 'package:flutter/material.dart';
import 'package:font_awesome_flutter/font_awesome_flutter.dart';

import 'package:senior_design_tokens/senior_design_tokens.dart';
import 'package:senior_design_system/senior_design_system.dart';

import '../widgets/page_wrapper.dart';

class BadgeExemple extends StatelessWidget {
  const BadgeExemple({Key? key}) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return PageWrapper(
      title: 'Badge',
      child: ListView(
        padding: EdgeInsets.all(SeniorSpacing.normal),
        children: [
          Padding(
            padding: const EdgeInsets.all(SeniorSpacing.normal),
            child: Text("Pills"),
          ),
          Wrap(
            spacing: SeniorSpacing.normal,
            runSpacing: SeniorSpacing.normal,
            children: [
              Column(
                crossAxisAlignment: CrossAxisAlignment.start,
                children: [
                  Padding(
                    padding: const EdgeInsets.all(
                      SeniorSpacing.xxsmall,
                    ),
                    child: SeniorBadge(
                      backgroundColor: SeniorColors.supportingColor,
                      fontColor: SeniorColors.pureWhite,
                      label: 'Supera as expectativas',
                      shape: SeniorBadgeShape.pill,
                    ),
                  ),
                  Padding(
                    padding: const EdgeInsets.all(SeniorSpacing.xxsmall),
                    child: SeniorBadge(
                      backgroundColor: SeniorColors.primaryColor400,
                      fontColor: SeniorColors.pureBlack,
                      label: 'Atende plenamente',
                      shape: SeniorBadgeShape.pill,
                    ),
                  ),
                  Padding(
                    padding: const EdgeInsets.all(SeniorSpacing.xxsmall),
                    child: SeniorBadge(
                      backgroundColor: SeniorColors.manchesterColorBlue,
                      fontColor: SeniorColors.pureWhite,
                      label: 'Atende satisfatoriamente',
                      shape: SeniorBadgeShape.pill,
                    ),
                  ),
                  Padding(
                    padding: const EdgeInsets.all(SeniorSpacing.xxsmall),
                    child: SeniorBadge(
                      backgroundColor: SeniorColors.manchesterColorYellow,
                      fontColor: SeniorColors.pureBlack,
                      label: 'Atende parcialmente',
                      shape: SeniorBadgeShape.pill,
                    ),
                  ),
                  Padding(
                    padding: const EdgeInsets.all(SeniorSpacing.xxsmall),
                    child: SeniorBadge(
                      backgroundColor: SeniorColors.manchesterColorRed,
                      fontColor: SeniorColors.pureWhite,
                      label: 'Não atende',
                      shape: SeniorBadgeShape.pill,
                    ),
                  ),
                ],
              ),
              Column(
                crossAxisAlignment: CrossAxisAlignment.start,
                children: [
                  Padding(
                    padding: const EdgeInsets.all(
                      SeniorSpacing.xxsmall,
                    ),
                    child: SeniorBadge(
                      backgroundColor: SeniorColors.supportingColor,
                      disabledBackgroundColor: SeniorColors.secondaryColor400,
                      fontColor: SeniorColors.pureWhite,
                      disabledFontColor: SeniorColors.pureWhite,
                      label: 'Supera as expectativas',
                      shape: SeniorBadgeShape.pill,
                      disabled: true,
                    ),
                  ),
                  Padding(
                    padding: const EdgeInsets.all(SeniorSpacing.xxsmall),
                    child: SeniorBadge(
                      backgroundColor: SeniorColors.primaryColor400,
                      disabledBackgroundColor: SeniorColors.secondaryColor400,
                      fontColor: SeniorColors.pureWhite,
                      disabledFontColor: SeniorColors.pureWhite,
                      label: 'Atende plenamente',
                      shape: SeniorBadgeShape.pill,
                      disabled: true,
                    ),
                  ),
                  Padding(
                    padding: const EdgeInsets.all(SeniorSpacing.xxsmall),
                    child: SeniorBadge(
                      backgroundColor: SeniorColors.manchesterColorBlue,
                      disabledBackgroundColor: SeniorColors.secondaryColor400,
                      fontColor: SeniorColors.pureWhite,
                      disabledFontColor: SeniorColors.pureWhite,
                      label: 'Atende satisfatoriamente',
                      shape: SeniorBadgeShape.pill,
                      disabled: true,
                    ),
                  ),
                  Padding(
                    padding: const EdgeInsets.all(SeniorSpacing.xxsmall),
                    child: SeniorBadge(
                      backgroundColor: SeniorColors.manchesterColorYellow,
                      disabledBackgroundColor: SeniorColors.secondaryColor400,
                      fontColor: SeniorColors.pureBlack,
                      disabledFontColor: SeniorColors.pureWhite,
                      label: 'Atende parcialmente',
                      shape: SeniorBadgeShape.pill,
                      disabled: true,
                    ),
                  ),
                  Padding(
                    padding: const EdgeInsets.all(SeniorSpacing.xxsmall),
                    child: SeniorBadge(
                      backgroundColor: SeniorColors.manchesterColorRed,
                      disabledBackgroundColor: SeniorColors.secondaryColor400,
                      fontColor: SeniorColors.pureWhite,
                      disabledFontColor: SeniorColors.pureWhite,
                      label: 'Não atende',
                      shape: SeniorBadgeShape.pill,
                      disabled: true,
                    ),
                  ),
                ],
              ),
            ],
          ),
          Padding(
            padding: const EdgeInsets.all(SeniorSpacing.normal),
            child: Text("Chips"),
          ),
          Wrap(
            spacing: SeniorSpacing.normal,
            runSpacing: SeniorSpacing.normal,
            children: [
              Padding(
                padding: const EdgeInsets.all(SeniorSpacing.xxsmall),
                child: SeniorBadge(
                  backgroundColor: SeniorColors.manchesterColorGreen,
                  fontColor: SeniorColors.pureWhite,
                  label: 'Enviado',
                  shape: SeniorBadgeShape.chip,
                ),
              ),
              Padding(
                padding: const EdgeInsets.all(SeniorSpacing.xxsmall),
                child: SeniorBadge(
                  backgroundColor: SeniorColors.manchesterColorBlue,
                  fontColor: SeniorColors.pureWhite,
                  label: 'Atendido',
                  shape: SeniorBadgeShape.chip,
                ),
              ),
              Padding(
                padding: const EdgeInsets.all(SeniorSpacing.xxsmall),
                child: SeniorBadge(
                  backgroundColor: SeniorColors.manchesterColorYellow,
                  fontColor: SeniorColors.pureBlack,
                  label: 'Aguardando',
                  shape: SeniorBadgeShape.chip,
                ),
              ),
              Padding(
                padding: const EdgeInsets.all(SeniorSpacing.xxsmall),
                child: SeniorBadge(
                  backgroundColor: SeniorColors.manchesterColorGreen,
                  disabledBackgroundColor: SeniorColors.secondaryColor400,
                  fontColor: SeniorColors.pureWhite,
                  disabledFontColor: SeniorColors.pureWhite,
                  label: 'Enviado',
                  shape: SeniorBadgeShape.chip,
                  disabled: true,
                ),
              ),
              Padding(
                padding: const EdgeInsets.all(SeniorSpacing.xxsmall),
                child: SeniorBadge(
                  backgroundColor: SeniorColors.manchesterColorBlue,
                  disabledBackgroundColor: SeniorColors.secondaryColor400,
                  fontColor: SeniorColors.pureWhite,
                  disabledFontColor: SeniorColors.pureWhite,
                  label: 'Atendido',
                  shape: SeniorBadgeShape.chip,
                  disabled: true,
                ),
              ),
              Padding(
                padding: const EdgeInsets.all(SeniorSpacing.xxsmall),
                child: SeniorBadge(
                  backgroundColor: SeniorColors.manchesterColorYellow,
                  disabledBackgroundColor: SeniorColors.secondaryColor400,
                  fontColor: SeniorColors.pureBlack,
                  disabledFontColor: SeniorColors.pureWhite,
                  label: 'Aguardando',
                  shape: SeniorBadgeShape.chip,
                  disabled: true,
                ),
              ),
            ],
          ),
          Padding(
            padding: const EdgeInsets.all(SeniorSpacing.normal),
            child: Text("Pill - Icons"),
          ),
          Wrap(
            spacing: SeniorSpacing.normal,
            runSpacing: SeniorSpacing.normal,
            children: [
              Column(
                crossAxisAlignment: CrossAxisAlignment.start,
                children: [
                  Padding(
                    padding: const EdgeInsets.all(
                      SeniorSpacing.xxsmall,
                    ),
                    child: SeniorBadge.icon(
                      backgroundColor: SeniorColors.supportingColor,
                      fontColor: SeniorColors.pureWhite,
                      icon: FontAwesomeIcons.laugh,
                      label: 'Supera as expectativas',
                      shape: SeniorBadgeShape.chip,
                    ),
                  ),
                  Padding(
                    padding: const EdgeInsets.all(SeniorSpacing.xxsmall),
                    child: SeniorBadge.icon(
                      backgroundColor: SeniorColors.primaryColor400,
                      fontColor: SeniorColors.pureBlack,
                      icon: FontAwesomeIcons.laughWink,
                      label: 'Atende plenamente',
                      shape: SeniorBadgeShape.chip,
                    ),
                  ),
                  Padding(
                    padding: const EdgeInsets.all(SeniorSpacing.xxsmall),
                    child: SeniorBadge.icon(
                      backgroundColor: SeniorColors.manchesterColorBlue,
                      fontColor: SeniorColors.pureWhite,
                      icon: FontAwesomeIcons.smileWink,
                      label: 'Atende satisfatoriamente',
                      shape: SeniorBadgeShape.chip,
                    ),
                  ),
                  Padding(
                    padding: const EdgeInsets.all(SeniorSpacing.xxsmall),
                    child: SeniorBadge.icon(
                      backgroundColor: SeniorColors.manchesterColorYellow,
                      fontColor: SeniorColors.pureBlack,
                      icon: FontAwesomeIcons.smile,
                      label: 'Atende parcialmente',
                      shape: SeniorBadgeShape.chip,
                    ),
                  ),
                  Padding(
                    padding: const EdgeInsets.all(SeniorSpacing.xxsmall),
                    child: SeniorBadge.icon(
                      backgroundColor: SeniorColors.manchesterColorRed,
                      fontColor: SeniorColors.pureWhite,
                      icon: FontAwesomeIcons.meh,
                      label: 'Não atende',
                      shape: SeniorBadgeShape.chip,
                    ),
                  ),
                ],
              ),
              Column(
                crossAxisAlignment: CrossAxisAlignment.start,
                children: [
                  Padding(
                    padding: const EdgeInsets.all(
                      SeniorSpacing.xxsmall,
                    ),
                    child: SeniorBadge.icon(
                      backgroundColor: SeniorColors.supportingColor,
                      fontColor: SeniorColors.pureWhite,
                      icon: FontAwesomeIcons.laugh,
                      label: 'Supera as expectativas',
                      shape: SeniorBadgeShape.pill,
                    ),
                  ),
                  Padding(
                    padding: const EdgeInsets.all(SeniorSpacing.xxsmall),
                    child: SeniorBadge.icon(
                      backgroundColor: SeniorColors.primaryColor400,
                      fontColor: SeniorColors.pureWhite,
                      icon: FontAwesomeIcons.laughWink,
                      label: 'Atende plenamente',
                      shape: SeniorBadgeShape.pill,
                    ),
                  ),
                  Padding(
                    padding: const EdgeInsets.all(SeniorSpacing.xxsmall),
                    child: SeniorBadge.icon(
                      backgroundColor: SeniorColors.manchesterColorBlue,
                      fontColor: SeniorColors.pureWhite,
                      icon: FontAwesomeIcons.smileWink,
                      label: 'Atende satisfatoriamente',
                      shape: SeniorBadgeShape.pill,
                    ),
                  ),
                  Padding(
                    padding: const EdgeInsets.all(SeniorSpacing.xxsmall),
                    child: SeniorBadge.icon(
                      backgroundColor: SeniorColors.manchesterColorYellow,
                      fontColor: SeniorColors.pureBlack,
                      icon: FontAwesomeIcons.smile,
                      label: 'Atende parcialmente',
                      shape: SeniorBadgeShape.pill,
                    ),
                  ),
                  Padding(
                    padding: const EdgeInsets.all(SeniorSpacing.xxsmall),
                    child: SeniorBadge.icon(
                      backgroundColor: SeniorColors.manchesterColorRed,
                      fontColor: SeniorColors.pureWhite,
                      icon: FontAwesomeIcons.meh,
                      label: 'Não atende',
                      shape: SeniorBadgeShape.pill,
                    ),
                  ),
                ],
              ),
            ],
          ),
        ],
      ),
    );
  }
}

==> senior_design_system-0.26.2.tar.gz: example/lib/pages/badge.example.dart <==
import 'package:flutter/material.dart';

import 'package:font_awesome_flutter/font_awesome_flutter.dart';
import 'package:senior_design_tokens/senior_design_tokens.dart';
import 'package:senior_design_system/senior_design_system.dart';

import '../widgets/page_wrapper.dart';

class BadgeExemple extends StatelessWidget {
  const BadgeExemple({Key? key}) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return PageWrapper(
      title: 'Badge',
      child: ListView(
        padding: const EdgeInsets.all(SeniorSpacing.normal),
        children: [
          const Padding(
            padding: EdgeInsets.all(SeniorSpacing.normal),
            child: Text('Pills'),
          ),
          Wrap(
            spacing: SeniorSpacing.normal,
            runSpacing: SeniorSpacing.normal,
            children: [
              Column(
                crossAxisAlignment: CrossAxisAlignment.start,
                children: [
                  const Padding(
                    padding: EdgeInsets.all(
                      SeniorSpacing.xxsmall,
                    ),
                    child: SeniorBadge(
                      backgroundColor: SeniorColors.supportingColor,
                      fontColor: SeniorColors.pureWhite,
                      label: 'Supera as expectativas',
                      shape: SeniorBadgeShape.pill,
                    ),
                  ),
                  const Padding(
                    padding: EdgeInsets.all(SeniorSpacing.xxsmall),
                    child: const SeniorBadge(
                      backgroundColor: SeniorColors.primaryColor400,
                      fontColor: SeniorColors.pureBlack,
                      label: 'Atende plenamente',
                      shape: SeniorBadgeShape.pill,
                    ),
                  ),
                  const Padding(
                    padding: EdgeInsets.all(SeniorSpacing.xxsmall),
                    child: const SeniorBadge(
                      backgroundColor: SeniorColors.manchesterColorBlue,
                      fontColor: SeniorColors.pureWhite,
                      label: 'Atende satisfatoriamente',
                      shape: SeniorBadgeShape.pill,
                    ),
                  ),
                  const Padding(
                    padding: EdgeInsets.all(SeniorSpacing.xxsmall),
                    child: SeniorBadge(
                      backgroundColor: SeniorColors.manchesterColorYellow,
                      fontColor: SeniorColors.pureBlack,
                      label: 'Atende parcialmente',
                      shape: SeniorBadgeShape.pill,
                    ),
                  ),
                  const Padding(
                    padding: EdgeInsets.all(SeniorSpacing.xxsmall),
                    child: const SeniorBadge(
                      backgroundColor: SeniorColors.manchesterColorRed,
                      fontColor: SeniorColors.pureWhite,
                      label: 'Não atende',
                      shape: SeniorBadgeShape.pill,
                    ),
                  ),
                ],
              ),
              Column(
                crossAxisAlignment: CrossAxisAlignment.start,
                children: [
                  const Padding(
                    padding: EdgeInsets.all(
                      SeniorSpacing.xxsmall,
                    ),
                    child: const SeniorBadge(
                      backgroundColor: SeniorColors.supportingColor,
                      disabledBackgroundColor: SeniorColors.secondaryColor400,
                      fontColor: SeniorColors.pureWhite,
                      disabledFontColor: SeniorColors.pureBlack,
                      label: 'Supera as expectativas',
                      shape: SeniorBadgeShape.pill,
                      disabled: true,
                    ),
                  ),
                  const Padding(
                    padding: EdgeInsets.all(SeniorSpacing.xxsmall),
                    child: SeniorBadge(
                      backgroundColor: SeniorColors.primaryColor400,
                      disabledBackgroundColor: SeniorColors.secondaryColor400,
                      fontColor: SeniorColors.pureWhite,
                      disabledFontColor: SeniorColors.pureBlack,
                      label: 'Atende plenamente',
                      shape: SeniorBadgeShape.pill,
                      disabled: true,
                    ),
                  ),
                  const Padding(
                    padding: EdgeInsets.all(SeniorSpacing.xxsmall),
                    child: const SeniorBadge(
                      backgroundColor: SeniorColors.manchesterColorBlue,
                      disabledBackgroundColor: SeniorColors.secondaryColor400,
                      fontColor: SeniorColors.pureWhite,
                      disabledFontColor: SeniorColors.pureBlack,
                      label: 'Atende satisfatoriamente',
                      shape: SeniorBadgeShape.pill,
                      disabled: true,
                    ),
                  ),
                  const Padding(
                    padding: EdgeInsets.all(SeniorSpacing.xxsmall),
                    child: const SeniorBadge(
                      backgroundColor: SeniorColors.manchesterColorYellow,
                      disabledBackgroundColor: SeniorColors.secondaryColor400,
                      fontColor: SeniorColors.pureBlack,
                      disabledFontColor: SeniorColors.pureBlack,
                      label: 'Atende parcialmente',
                      shape: SeniorBadgeShape.pill,
                      disabled: true,
                    ),
                  ),
                  const Padding(
                    padding: EdgeInsets.all(SeniorSpacing.xxsmall),
                    child: const SeniorBadge(
                      backgroundColor: SeniorColors.manchesterColorRed,
                      disabledBackgroundColor: SeniorColors.secondaryColor400,
                      fontColor: SeniorColors.pureWhite,
                      disabledFontColor: SeniorColors.pureBlack,
                      label: 'Não atende',
                      shape: SeniorBadgeShape.pill,
                      disabled: true,
                    ),
                  ),
                ],
              ),
            ],
          ),
          const Padding(
            padding: EdgeInsets.all(SeniorSpacing.normal),
            child: Text('Chips'),
          ),
          Wrap(
            spacing: SeniorSpacing.normal,
            runSpacing: SeniorSpacing.normal,
            children: [
              const Padding(
                padding: EdgeInsets.all(SeniorSpacing.xxsmall),
                child: const SeniorBadge(
                  backgroundColor: SeniorColors.manchesterColorGreen,
                  fontColor: SeniorColors.pureWhite,
                  label: 'Enviado',
                  shape: SeniorBadgeShape.chip,
                ),
              ),
              const Padding(
                padding: EdgeInsets.all(SeniorSpacing.xxsmall),
                child: const SeniorBadge(
                  backgroundColor: SeniorColors.manchesterColorBlue,
                  fontColor: SeniorColors.pureBlack,
                  label: 'Atendido',
                  shape: SeniorBadgeShape.chip,
                ),
              ),
              const Padding(
                padding: EdgeInsets.all(SeniorSpacing.xxsmall),
                child: const SeniorBadge(
                  backgroundColor: SeniorColors.manchesterColorYellow,
                  fontColor: SeniorColors.pureBlack,
                  label: 'Aguardando',
                  shape: SeniorBadgeShape.chip,
                ),
              ),
              const Padding(
                padding: EdgeInsets.all(SeniorSpacing.xxsmall),
                child: const SeniorBadge(
                  backgroundColor: SeniorColors.manchesterColorGreen,
                  disabledBackgroundColor: SeniorColors.secondaryColor400,
                  fontColor: SeniorColors.pureWhite,
                  disabledFontColor: SeniorColors.pureBlack,
                  label: 'Enviado',
                  shape: SeniorBadgeShape.chip,
                  disabled: true,
                ),
              ),
              const Padding(
                padding: EdgeInsets.all(SeniorSpacing.xxsmall),
                child: SeniorBadge(
                  backgroundColor: SeniorColors.manchesterColorBlue,
                  disabledBackgroundColor: SeniorColors.secondaryColor400,
                  fontColor: SeniorColors.pureWhite,
                  disabledFontColor: SeniorColors.pureBlack,
                  label: 'Atendido',
                  shape: SeniorBadgeShape.chip,
                  disabled: true,
                ),
              ),
              const Padding(
                padding: EdgeInsets.all(SeniorSpacing.xxsmall),
                child: const SeniorBadge(
                  backgroundColor: SeniorColors.manchesterColorYellow,
                  disabledBackgroundColor: SeniorColors.secondaryColor400,
                  fontColor: SeniorColors.pureBlack,
                  disabledFontColor: SeniorColors.pureBlack,
                  label: 'Aguardando',
                  shape: SeniorBadgeShape.chip,
                  disabled: true,
                ),
              ),
            ],
          ),
          const Padding(
            padding: EdgeInsets.all(SeniorSpacing.normal),
            child: const Text('Pill - Icons'),
          ),
          Wrap(
            spacing: SeniorSpacing.normal,
            runSpacing: SeniorSpacing.normal,
            children: [
              Column(
                crossAxisAlignment: CrossAxisAlignment.start,
                children: [
                  Padding(
                    padding: const EdgeInsets.all(
                      SeniorSpacing.xxsmall,
                    ),
                    child: SeniorBadge.icon(
                      backgroundColor: SeniorColors.supportingColor,
                      fontColor: SeniorColors.pureWhite,
                      icon: FontAwesomeIcons.faceLaugh,
                      label: 'Supera as expectativas',
                      shape: SeniorBadgeShape.chip,
                    ),
                  ),
                  Padding(
                    padding: const EdgeInsets.all(SeniorSpacing.xxsmall),
                    child: SeniorBadge.icon(
                      backgroundColor: SeniorColors.primaryColor400,
                      fontColor: SeniorColors.pureBlack,
                      icon: FontAwesomeIcons.faceLaughWink,
                      label: 'Atende plenamente',
                      shape: SeniorBadgeShape.chip,
                    ),
                  ),
                  Padding(
                    padding: const EdgeInsets.all(SeniorSpacing.xxsmall),
                    child: SeniorBadge.icon(
                      backgroundColor: SeniorColors.manchesterColorBlue,
                      fontColor: SeniorColors.pureWhite,
                      icon: FontAwesomeIcons.faceSmileWink,
                      label: 'Atende satisfatoriamente',
                      shape: SeniorBadgeShape.chip,
                    ),
                  ),
                  Padding(
                    padding: const EdgeInsets.all(SeniorSpacing.xxsmall),
                    child: SeniorBadge.icon(
                      backgroundColor: SeniorColors.manchesterColorYellow,
                      fontColor: SeniorColors.pureBlack,
                      icon: FontAwesomeIcons.faceSmile,
                      label: 'Atende parcialmente',
                      shape: SeniorBadgeShape.chip,
                    ),
                  ),
                  Padding(
                    padding: const EdgeInsets.all(SeniorSpacing.xxsmall),
                    child: SeniorBadge.icon(
                      backgroundColor: SeniorColors.manchesterColorRed,
                      fontColor: SeniorColors.pureWhite,
                      icon: FontAwesomeIcons.faceMeh,
                      label: 'Não atende',
                      shape: SeniorBadgeShape.chip,
                    ),
                  ),
                ],
              ),
              Column(
                crossAxisAlignment: CrossAxisAlignment.start,
                children: [
                  Padding(
                    padding: const EdgeInsets.all(
                      SeniorSpacing.xxsmall,
                    ),
                    child: SeniorBadge.icon(
                      backgroundColor: SeniorColors.supportingColor,
                      fontColor: SeniorColors.pureWhite,
                      icon: FontAwesomeIcons.faceLaugh,
                      label: 'Supera as expectativas',
                      shape: SeniorBadgeShape.pill,
                    ),
                  ),
                  Padding(
                    padding: const EdgeInsets.all(SeniorSpacing.xxsmall),
                    child: SeniorBadge.icon(
                      backgroundColor: SeniorColors.primaryColor400,
                      fontColor: SeniorColors.pureWhite,
                      icon: FontAwesomeIcons.faceLaughWink,
                      label: 'Atende plenamente',
                      shape: SeniorBadgeShape.pill,
                    ),
                  ),
                  Padding(
                    padding: const EdgeInsets.all(SeniorSpacing.xxsmall),
                    child: SeniorBadge.icon(
                      backgroundColor: SeniorColors.manchesterColorBlue,
                      fontColor: SeniorColors.pureWhite,
                      icon: FontAwesomeIcons.faceSmileWink,
                      label: 'Atende satisfatoriamente',
                      shape: SeniorBadgeShape.pill,
                    ),
                  ),
                  Padding(
                    padding: const EdgeInsets.all(SeniorSpacing.xxsmall),
                    child: SeniorBadge.icon(
                      backgroundColor: SeniorColors.manchesterColorYellow,
                      fontColor: SeniorColors.pureBlack,
                      icon: FontAwesomeIcons.faceSmile,
                      label: 'Atende parcialmente',
                      shape: SeniorBadgeShape.pill,
                    ),
                  ),
                  Padding(
                    padding: const EdgeInsets.all(SeniorSpacing.xxsmall),
                    child: SeniorBadge.icon(
                      backgroundColor: SeniorColors.manchesterColorRed,
                      fontColor: SeniorColors.pureWhite,
                      icon: FontAwesomeIcons.faceMeh,
                      label: 'Não atende',
                      shape: SeniorBadgeShape.pill,
                    ),
                  ),
                ],
              ),
            ],
          ),
        ],
      ),
    );
  }
}
